" Specify a directory for plugins
" - For Neovim: stdpath('data') . '/plugged'
" - Avoid using standard Vim directory names like 'plugin'
call plug#begin('~/.vim/plugged')

"" Syntax Highlighting
" php.vim: PHP syntax higlighting
Plug 'StanAngeloff/php.vim'

"" Debugger
" v-debug: PHP Debugger with xdebug
Plug 'vim-vdebug/vdebug'

"" Syntax Linting/Checking
" Ale: Runs fast and works well.
Plug 'dense-analysis/ale'
Plug 'vim-scripts/AutoComplPop'
"" GUI
" NERDTree: Sidebar file tree
Plug 'scrooloose/nerdtree'
Plug 'Xuyuanp/nerdtree-git-plugin'

" MINIBUFXPL: A nice buffer explorer
Plug 'fholgado/minibufexpl.vim'

" Airline: Some file infos
Plug 'vim-airline/vim-airline'

"" Indexing
" ctrlp.vim: Quickly find files by name without navigating
Plug 'kien/ctrlp.vim'

" fzf.vim: Quickly finds file content
" Plug 'junegunn/fzf', { 'do': './install --bin' }
" Plug 'junegunn/fzf.vim'

Plug 'mileszs/ack.vim'

"" Input optimization
" Vim Surround: Quickly surround stuff
Plug 'tpope/vim-surround'

" Initialize plugin system
call plug#end()

"" vim config
" Intendation
set tabstop=4
set softtabstop=4
set shiftwidth=4
set expandtab
set autoindent

"" NERDTree config
" Autostart NERDTree on start
autocmd vimenter * NERDTree | wincmd w

" Close vim if the only window left open is a NERDTree
autocmd bufenter * if (winnr("$") == 1 && exists("b:NERDTree") && b:NERDTree.isTabTree()) | q | endif

"" ALE config
" Enable autocomplete
let g:ale_completion_enabled = 1

" Hijack Vim's omnifunc 
set omnifunc=ale#completion#OmniFunc

" Some autocompletion settings.
set completeopt+=longest,menuone,menu,preview

"" vdebug config
" Set xdebug config
let g:vdebug_options = {'ide_key': 'PHPSTORM'}
let g:vdebug_options = {'break_on_open': 0}
let g:vdebug_options = {'server': '172.17.0.1'}
let g:vdebug_options = {'port': '9002'}

let g:vdebug_options["path_maps"] = { "/var/www/html": "/home/leong/workspace/project" }

"" CtrlP config
" Self explainatory
let g:ctrlp_max_files=0
let g:ctrlp_max_depth=40
let g:ctrlp_custom_ignore = 'node_modules\|DS_Store\|git'
